@@ -1,9 +1,9 @@
 reducs <-
 function (s, cl) 
 {
-    if (isTRUE(attr(s, "class")[1] == "Semigroup") == FALSE) 
+    if (isTRUE("Semigroup" %in% attr(s, "class")) == FALSE) 
         stop("\"s\" should be an object of a \"Semigroup\" class.")
-    ifelse(isTRUE(attr(s, "class")[2] == "symbolic") == TRUE, 
+    ifelse(isTRUE("symbolic" %in% attr(s, "class")) == TRUE, 
         sx <- as.semigroup(s, numerical = TRUE), sx <- s)
     n <- nlevels(factor(cl))
     cls <- list()
@@ -18,7 +18,7 @@ function (s, cl)
             for (q in seq_along(cls)) {
                 if (all(unique(as.vector(unlist(sx$S[which(cl == 
                   i), which(cl == j)]))) %in% cls[[q]]) == TRUE) {
-                  ifelse(isTRUE(attr(s, "class")[2] == "symbolic") == 
+                  ifelse(isTRUE("symbolic" %in% attr(s, "class")) == 
                     TRUE, bm[i, j] <- bm[i, j] <- s$st[min(cls[[q]])], 
                     bm[i, j] <- bm[i, j] <- as.numeric(dimnames(sx$S)[[1]])[min(cls[[q]])])
                   break
@@ -34,7 +34,7 @@ function (s, cl)
     rm(i)
     lbs <- vector()
     for (i in seq_along(tabulate(cl))) {
-        ifelse(isTRUE(attr(s, "class")[2] == "symbolic") == TRUE, 
+        ifelse(isTRUE("symbolic" %in% attr(s, "class")) == TRUE, 
             lbs <- append(lbs, s$st[which(cl == i)[1]]), lbs <- append(lbs, 
                 as.numeric(dimnames(sx$S)[[1]])[which(cl == i)[1]]))
     }
